
rm(list=ls())
library(methods)
library(devtools)
library(spatsurv)
library(sp)

env <- Sys.getenv()

SEEDx = as.numeric(env["SEED"])
ii = as.numeric(env["I"])
datapath = env["DATAPATH"]

load(file.path(datapath,"simulated_datasets.RData"))

i = ii
SEED = SEEDx

message("Ready: SEED = ",SEED, " i = ",i," data path = ",datapath)

betaprior <- betapriorGauss(mean = 0, sd = 10)
omegaprior <- omegapriorGauss(mean = 0, sd = 10)
etaprior <- etapriorGauss(mean = c(0, -3), sd = c(0.5,0.4))

priors <- mcmcPriors(   betaprior = betaprior,
                        omegaprior = omegaprior,
                        etaprior = etaprior,
                        call = indepGaussianprior,
                        derivative = derivindepGaussianprior)

###for(SEED in c(1,2,3)){
set.seed(SEED)

###    for(i in 1:16){

message("Analysing dataset ",i," with seed ",SEED)

haz <- exponentialHaz()
if(i>8){
    haz <- weibullHaz()
}


mod <- survspat(formula = ss ~ age + sex,
                data = get(paste("spatdat",i,sep="")),
                dist = haz,
                cov.model = ExponentialCovFct(),
                mcmc.control = mcmcpars(nits = 1000000,
                    burn = 10000,
                    thin = 990),
                control=inference.control(gridded=TRUE,cellwidth=0.034),
                priors = priors)

save(list=ls(),file=file.path(datapath,paste("results_",SEED,"_",i,".RData",sep="")))

###    }
###}
