rm(list=ls())

DATAPATH <- Sys.getenv("DATAPATH")

library(devtools)
library(spatsurv)
library(sp)
library(survival)

set.seed(1)   

n <- 500

omega_list <- list()
omega_list[[1]] <- 0.25
omega_list[[2]] <- 0.5
omega_list[[3]] <- 0.75
omega_list[[4]] <- 1
omega_list[[5]] <- 1.25
omega_list[[6]] <- 1.5
omega_list[[7]] <- 1.75
omega_list[[8]] <- 2
omega_list[[9]] <- c(0.25,1)
omega_list[[10]] <- c(0.5,1)
omega_list[[11]] <- c(0.75,1)
omega_list[[12]] <- c(1,1)
omega_list[[13]] <- c(0.25,2)
omega_list[[14]] <- c(0.5,2)
omega_list[[15]] <- c(0.75,2)
omega_list[[16]] <- c(1,2)

cov_pars_list <- list()
cov_pars_list[[1]] <- c(0.5,0.02)
cov_pars_list[[2]] <- c(1,0.02)
cov_pars_list[[3]] <- c(1.5,0.02)
cov_pars_list[[4]] <- c(2,0.02)
cov_pars_list[[5]] <- c(0.5,0.05)
cov_pars_list[[6]] <- c(1,0.05)
cov_pars_list[[7]] <- c(1.5,0.05)
cov_pars_list[[8]] <- c(2,0.05)
cov_pars_list[[9]] <- c(0.5,0.1)
cov_pars_list[[10]] <- c(1,0.1)
cov_pars_list[[11]] <- c(1.5,0.1)
cov_pars_list[[12]] <- c(2,0.1)
cov_pars_list[[13]] <- c(0.5,0.15)
cov_pars_list[[14]] <- c(1,0.15)
cov_pars_list[[15]] <- c(1.5,0.15)
cov_pars_list[[16]] <- c(2,0.15)

beta_list <- list()
beta_list[[1]] <- c(0.03,0.03)
beta_list[[2]] <- c(0.06,0.03)
beta_list[[3]] <- c(0.09,0.03)
beta_list[[4]] <- c(0.12,0.03)
beta_list[[5]] <- c(0.03,0.09)
beta_list[[6]] <- c(0.06,0.09)
beta_list[[7]] <- c(0.09,0.09)
beta_list[[8]] <- c(0.12,0.09)
beta_list[[9]] <- c(0.03,0.15)
beta_list[[10]] <- c(0.06,0.15)
beta_list[[11]] <- c(0.09,0.15)
beta_list[[12]] <- c(0.12,0.15)
beta_list[[13]] <- c(0.03,0.21)
beta_list[[14]] <- c(0.06,0.21)
beta_list[[15]] <- c(0.09,0.21)
beta_list[[16]] <- c(0.12,0.21)



for(i in 1:16){
    print(i)

    haz <- exponentialHaz()
    if(i>8){
        haz <- weibullHaz()
    }

    dat <- simsurv(X=cbind( age=runif(n,5,50),sex=rbinom(n,1,0.5)),
                            beta=beta_list[[i]],
                            dist=haz,
                            omega=omega_list[[i]],
                            cov.parameters=cov_pars_list[[i]],
                            cov.model=ExponentialCovFct(),
                            mcmc.control=mcmcpars(nits=100000,burn=10000,thin=1000))  

    survtimes <- dat$survtimes
    censtimes <- rexp(n,1/mean(survtimes))                                    
    survdat <- gencens(survtimes,censtimes) 

    coords <- dat$coords
    X <- as.data.frame(dat$X) # covariates 
    spatdat <- SpatialPointsDataFrame(coords,data=as.data.frame(X))
    spatdat$ss <- survdat

    assign(paste("spatdat",i,sep=""),spatdat)
    assign(paste("dat",i,sep=""),dat)
    assign(paste("censtimes",i,sep=""),censtimes)
}

save(list=ls(),file=file.path(DATAPATH, "simulated_datasets.RData"))

